ZettlePluginResponse class

Response returned from native platform

Constructors

ZettlePluginResponse.fromMap(Map response)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ Map?
getter/setter pair
methodName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited