ZettleRefundRequest class

Refund object.

Constructors

ZettleRefundRequest({int? refundAmount, int? taxAmount, required String reference, String? receiptNumber})

Properties

hashCode → int
The hash code for this object.
no setterinherited
receiptNumber ↔ String?
An identifier associated with the transaction that can be used to retrieve details related to the transaction.
getter/setter pair
reference ↔ String
An identifier associated with the transaction that can be used to retrieve details related to the transaction.
getter/setter pair
refundAmount ↔ int?
Total refund amount.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxAmount ↔ int?
Total refund amount.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited